# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BondMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fee': 'str',
        'memo': 'str',
        'node_address': 'str',
        'provider': 'str'
    }

    attribute_map = {
        'fee': 'fee',
        'memo': 'memo',
        'node_address': 'nodeAddress',
        'provider': 'provider'
    }

    def __init__(self, fee=None, memo=None, node_address=None, provider=None):  # noqa: E501
        """BondMetadata - a model defined in Swagger"""  # noqa: E501
        self._fee = None
        self._memo = None
        self._node_address = None
        self._provider = None
        self.discriminator = None
        if fee is not None:
            self.fee = fee
        self.memo = memo
        self.node_address = node_address
        if provider is not None:
            self.provider = provider

    @property
    def fee(self):
        """Gets the fee of this BondMetadata.  # noqa: E501

        node operator fee  # noqa: E501

        :return: The fee of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this BondMetadata.

        node operator fee  # noqa: E501

        :param fee: The fee of this BondMetadata.  # noqa: E501
        :type: str
        """

        self._fee = fee

    @property
    def memo(self):
        """Gets the memo of this BondMetadata.  # noqa: E501

        Transaction memo of bond event  # noqa: E501

        :return: The memo of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this BondMetadata.

        Transaction memo of bond event  # noqa: E501

        :param memo: The memo of this BondMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def node_address(self):
        """Gets the node_address of this BondMetadata.  # noqa: E501

        node address  # noqa: E501

        :return: The node_address of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this BondMetadata.

        node address  # noqa: E501

        :param node_address: The node_address of this BondMetadata.  # noqa: E501
        :type: str
        """
        if node_address is None:
            raise ValueError("Invalid value for `node_address`, must not be `None`")  # noqa: E501

        self._node_address = node_address

    @property
    def provider(self):
        """Gets the provider of this BondMetadata.  # noqa: E501

        bond provider address  # noqa: E501

        :return: The provider of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this BondMetadata.

        bond provider address  # noqa: E501

        :param provider: The provider of this BondMetadata.  # noqa: E501
        :type: str
        """

        self._provider = provider

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BondMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BondMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RunePriceMeta(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_rune_price_usd': 'str',
        'end_time': 'str',
        'start_rune_price_usd': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'end_rune_price_usd': 'endRunePriceUSD',
        'end_time': 'endTime',
        'start_rune_price_usd': 'startRunePriceUSD',
        'start_time': 'startTime'
    }

    def __init__(self, end_rune_price_usd=None, end_time=None, start_rune_price_usd=None, start_time=None):  # noqa: E501
        """RunePriceMeta - a model defined in Swagger"""  # noqa: E501
        self._end_rune_price_usd = None
        self._end_time = None
        self._start_rune_price_usd = None
        self._start_time = None
        self.discriminator = None
        self.end_rune_price_usd = end_rune_price_usd
        self.end_time = end_time
        self.start_rune_price_usd = start_rune_price_usd
        self.start_time = start_time

    @property
    def end_rune_price_usd(self):
        """Gets the end_rune_price_usd of this RunePriceMeta.  # noqa: E501

        Int64(e8), The price of Rune based on the USD pools at the end of the interval   # noqa: E501

        :return: The end_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_rune_price_usd

    @end_rune_price_usd.setter
    def end_rune_price_usd(self, end_rune_price_usd):
        """Sets the end_rune_price_usd of this RunePriceMeta.

        Int64(e8), The price of Rune based on the USD pools at the end of the interval   # noqa: E501

        :param end_rune_price_usd: The end_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if end_rune_price_usd is None:
            raise ValueError("Invalid value for `end_rune_price_usd`, must not be `None`")  # noqa: E501

        self._end_rune_price_usd = end_rune_price_usd

    @property
    def end_time(self):
        """Gets the end_time of this RunePriceMeta.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this RunePriceMeta.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def start_rune_price_usd(self):
        """Gets the start_rune_price_usd of this RunePriceMeta.  # noqa: E501

        Int64(e8), The price of Rune based on the USD pools at the start of the interval   # noqa: E501

        :return: The start_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_rune_price_usd

    @start_rune_price_usd.setter
    def start_rune_price_usd(self, start_rune_price_usd):
        """Sets the start_rune_price_usd of this RunePriceMeta.

        Int64(e8), The price of Rune based on the USD pools at the start of the interval   # noqa: E501

        :param start_rune_price_usd: The start_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if start_rune_price_usd is None:
            raise ValueError("Invalid value for `start_rune_price_usd`, must not be `None`")  # noqa: E501

        self._start_rune_price_usd = start_rune_price_usd

    @property
    def start_time(self):
        """Gets the start_time of this RunePriceMeta.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this RunePriceMeta.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunePriceMeta, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunePriceMeta):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ThornameMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'chain': 'str',
        'expire': 'str',
        'fund_amount': 'str',
        'memo': 'str',
        'owner': 'str',
        'registration_fee': 'str',
        'thorname': 'str',
        'tx_type': 'str'
    }

    attribute_map = {
        'address': 'address',
        'chain': 'chain',
        'expire': 'expire',
        'fund_amount': 'fundAmount',
        'memo': 'memo',
        'owner': 'owner',
        'registration_fee': 'registrationFee',
        'thorname': 'thorname',
        'tx_type': 'txType'
    }

    def __init__(self, address=None, chain=None, expire=None, fund_amount=None, memo=None, owner=None, registration_fee=None, thorname=None, tx_type=None):  # noqa: E501
        """ThornameMetadata - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._chain = None
        self._expire = None
        self._fund_amount = None
        self._memo = None
        self._owner = None
        self._registration_fee = None
        self._thorname = None
        self._tx_type = None
        self.discriminator = None
        self.address = address
        self.chain = chain
        self.expire = expire
        self.fund_amount = fund_amount
        self.memo = memo
        self.owner = owner
        self.registration_fee = registration_fee
        self.thorname = thorname
        self.tx_type = tx_type

    @property
    def address(self):
        """Gets the address of this ThornameMetadata.  # noqa: E501

        The CHAIN address thorname has been registered to.  # noqa: E501

        :return: The address of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ThornameMetadata.

        The CHAIN address thorname has been registered to.  # noqa: E501

        :param address: The address of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def chain(self):
        """Gets the chain of this ThornameMetadata.  # noqa: E501

        The thorname's chain.  # noqa: E501

        :return: The chain of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this ThornameMetadata.

        The thorname's chain.  # noqa: E501

        :param chain: The chain of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if chain is None:
            raise ValueError("Invalid value for `chain`, must not be `None`")  # noqa: E501

        self._chain = chain

    @property
    def expire(self):
        """Gets the expire of this ThornameMetadata.  # noqa: E501

        Int64, THORChain block height in which THORName expires.  # noqa: E501

        :return: The expire of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._expire

    @expire.setter
    def expire(self, expire):
        """Sets the expire of this ThornameMetadata.

        Int64, THORChain block height in which THORName expires.  # noqa: E501

        :param expire: The expire of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if expire is None:
            raise ValueError("Invalid value for `expire`, must not be `None`")  # noqa: E501

        self._expire = expire

    @property
    def fund_amount(self):
        """Gets the fund_amount of this ThornameMetadata.  # noqa: E501

        Int64, the amount of funding for the THORName registration.  # noqa: E501

        :return: The fund_amount of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._fund_amount

    @fund_amount.setter
    def fund_amount(self, fund_amount):
        """Sets the fund_amount of this ThornameMetadata.

        Int64, the amount of funding for the THORName registration.  # noqa: E501

        :param fund_amount: The fund_amount of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if fund_amount is None:
            raise ValueError("Invalid value for `fund_amount`, must not be `None`")  # noqa: E501

        self._fund_amount = fund_amount

    @property
    def memo(self):
        """Gets the memo of this ThornameMetadata.  # noqa: E501

        Transaction memo of thorname deposit message.  # noqa: E501

        :return: The memo of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this ThornameMetadata.

        Transaction memo of thorname deposit message.  # noqa: E501

        :param memo: The memo of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def owner(self):
        """Gets the owner of this ThornameMetadata.  # noqa: E501

        owner's THOR address.  # noqa: E501

        :return: The owner of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this ThornameMetadata.

        owner's THOR address.  # noqa: E501

        :param owner: The owner of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if owner is None:
            raise ValueError("Invalid value for `owner`, must not be `None`")  # noqa: E501

        self._owner = owner

    @property
    def registration_fee(self):
        """Gets the registration_fee of this ThornameMetadata.  # noqa: E501

        Int64, the registration fee paid.  # noqa: E501

        :return: The registration_fee of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._registration_fee

    @registration_fee.setter
    def registration_fee(self, registration_fee):
        """Sets the registration_fee of this ThornameMetadata.

        Int64, the registration fee paid.  # noqa: E501

        :param registration_fee: The registration_fee of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if registration_fee is None:
            raise ValueError("Invalid value for `registration_fee`, must not be `None`")  # noqa: E501

        self._registration_fee = registration_fee

    @property
    def thorname(self):
        """Gets the thorname of this ThornameMetadata.  # noqa: E501

        The thorname registered to the address.  # noqa: E501

        :return: The thorname of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._thorname

    @thorname.setter
    def thorname(self, thorname):
        """Sets the thorname of this ThornameMetadata.

        The thorname registered to the address.  # noqa: E501

        :param thorname: The thorname of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if thorname is None:
            raise ValueError("Invalid value for `thorname`, must not be `None`")  # noqa: E501

        self._thorname = thorname

    @property
    def tx_type(self):
        """Gets the tx_type of this ThornameMetadata.  # noqa: E501

        The type of the transaction given from its Memo.  # noqa: E501

        :return: The tx_type of this ThornameMetadata.  # noqa: E501
        :rtype: str
        """
        return self._tx_type

    @tx_type.setter
    def tx_type(self, tx_type):
        """Sets the tx_type of this ThornameMetadata.

        The type of the transaction given from its Memo.  # noqa: E501

        :param tx_type: The tx_type of this ThornameMetadata.  # noqa: E501
        :type: str
        """
        if tx_type is None:
            raise ValueError("Invalid value for `tx_type`, must not be `None`")  # noqa: E501

        self._tx_type = tx_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ThornameMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThornameMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddLiquidityMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affiliate_address': 'str',
        'affiliate_fee': 'str',
        'liquidity_units': 'str',
        'memo': 'str'
    }

    attribute_map = {
        'affiliate_address': 'affiliateAddress',
        'affiliate_fee': 'affiliateFee',
        'liquidity_units': 'liquidityUnits',
        'memo': 'memo'
    }

    def __init__(self, affiliate_address=None, affiliate_fee=None, liquidity_units=None, memo=None):  # noqa: E501
        """AddLiquidityMetadata - a model defined in Swagger"""  # noqa: E501
        self._affiliate_address = None
        self._affiliate_fee = None
        self._liquidity_units = None
        self._memo = None
        self.discriminator = None
        self.affiliate_address = affiliate_address
        self.affiliate_fee = affiliate_fee
        self.liquidity_units = liquidity_units
        self.memo = memo

    @property
    def affiliate_address(self):
        """Gets the affiliate_address of this AddLiquidityMetadata.  # noqa: E501

        Affiliate fee address of the addLiquidity  # noqa: E501

        :return: The affiliate_address of this AddLiquidityMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_address

    @affiliate_address.setter
    def affiliate_address(self, affiliate_address):
        """Sets the affiliate_address of this AddLiquidityMetadata.

        Affiliate fee address of the addLiquidity  # noqa: E501

        :param affiliate_address: The affiliate_address of this AddLiquidityMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_address is None:
            raise ValueError("Invalid value for `affiliate_address`, must not be `None`")  # noqa: E501

        self._affiliate_address = affiliate_address

    @property
    def affiliate_fee(self):
        """Gets the affiliate_fee of this AddLiquidityMetadata.  # noqa: E501

        Int64 (Basis points, 0-1000, where 1000=10%)  # noqa: E501

        :return: The affiliate_fee of this AddLiquidityMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_fee

    @affiliate_fee.setter
    def affiliate_fee(self, affiliate_fee):
        """Sets the affiliate_fee of this AddLiquidityMetadata.

        Int64 (Basis points, 0-1000, where 1000=10%)  # noqa: E501

        :param affiliate_fee: The affiliate_fee of this AddLiquidityMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_fee is None:
            raise ValueError("Invalid value for `affiliate_fee`, must not be `None`")  # noqa: E501

        self._affiliate_fee = affiliate_fee

    @property
    def liquidity_units(self):
        """Gets the liquidity_units of this AddLiquidityMetadata.  # noqa: E501

        Int64, amount of liquidity units assigned to the member as result of the liquidity deposit   # noqa: E501

        :return: The liquidity_units of this AddLiquidityMetadata.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_units

    @liquidity_units.setter
    def liquidity_units(self, liquidity_units):
        """Sets the liquidity_units of this AddLiquidityMetadata.

        Int64, amount of liquidity units assigned to the member as result of the liquidity deposit   # noqa: E501

        :param liquidity_units: The liquidity_units of this AddLiquidityMetadata.  # noqa: E501
        :type: str
        """
        if liquidity_units is None:
            raise ValueError("Invalid value for `liquidity_units`, must not be `None`")  # noqa: E501

        self._liquidity_units = liquidity_units

    @property
    def memo(self):
        """Gets the memo of this AddLiquidityMetadata.  # noqa: E501

        Transaction memo of the addLiquidity action  # noqa: E501

        :return: The memo of this AddLiquidityMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this AddLiquidityMetadata.

        Transaction memo of the addLiquidity action  # noqa: E501

        :param memo: The memo of this AddLiquidityMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddLiquidityMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddLiquidityMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RUNEPoolProvider(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'date_first_added': 'str',
        'date_last_added': 'str',
        'rune_added': 'str',
        'rune_address': 'str',
        'rune_deposit': 'str',
        'rune_withdrawn': 'str',
        'units': 'str'
    }

    attribute_map = {
        'date_first_added': 'dateFirstAdded',
        'date_last_added': 'dateLastAdded',
        'rune_added': 'runeAdded',
        'rune_address': 'runeAddress',
        'rune_deposit': 'runeDeposit',
        'rune_withdrawn': 'runeWithdrawn',
        'units': 'units'
    }

    def __init__(self, date_first_added=None, date_last_added=None, rune_added=None, rune_address=None, rune_deposit=None, rune_withdrawn=None, units=None):  # noqa: E501
        """RUNEPoolProvider - a model defined in Swagger"""  # noqa: E501
        self._date_first_added = None
        self._date_last_added = None
        self._rune_added = None
        self._rune_address = None
        self._rune_deposit = None
        self._rune_withdrawn = None
        self._units = None
        self.discriminator = None
        self.date_first_added = date_first_added
        self.date_last_added = date_last_added
        self.rune_added = rune_added
        self.rune_address = rune_address
        self.rune_deposit = rune_deposit
        self.rune_withdrawn = rune_withdrawn
        self.units = units

    @property
    def date_first_added(self):
        """Gets the date_first_added of this RUNEPoolProvider.  # noqa: E501

        Int64, Unix timestamp for the first time member deposited into the RUNEPool  # noqa: E501

        :return: The date_first_added of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._date_first_added

    @date_first_added.setter
    def date_first_added(self, date_first_added):
        """Sets the date_first_added of this RUNEPoolProvider.

        Int64, Unix timestamp for the first time member deposited into the RUNEPool  # noqa: E501

        :param date_first_added: The date_first_added of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if date_first_added is None:
            raise ValueError("Invalid value for `date_first_added`, must not be `None`")  # noqa: E501

        self._date_first_added = date_first_added

    @property
    def date_last_added(self):
        """Gets the date_last_added of this RUNEPoolProvider.  # noqa: E501

        Int64, Unix timestamp for the last time member deposited into the RUNEPool  # noqa: E501

        :return: The date_last_added of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._date_last_added

    @date_last_added.setter
    def date_last_added(self, date_last_added):
        """Sets the date_last_added of this RUNEPoolProvider.

        Int64, Unix timestamp for the last time member deposited into the RUNEPool  # noqa: E501

        :param date_last_added: The date_last_added of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if date_last_added is None:
            raise ValueError("Invalid value for `date_last_added`, must not be `None`")  # noqa: E501

        self._date_last_added = date_last_added

    @property
    def rune_added(self):
        """Gets the rune_added of this RUNEPoolProvider.  # noqa: E501

        Int64(e8), total asset added in the RUNEPool by member  # noqa: E501

        :return: The rune_added of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_added

    @rune_added.setter
    def rune_added(self, rune_added):
        """Sets the rune_added of this RUNEPoolProvider.

        Int64(e8), total asset added in the RUNEPool by member  # noqa: E501

        :param rune_added: The rune_added of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_added is None:
            raise ValueError("Invalid value for `rune_added`, must not be `None`")  # noqa: E501

        self._rune_added = rune_added

    @property
    def rune_address(self):
        """Gets the rune_address of this RUNEPoolProvider.  # noqa: E501

        address used by the member  # noqa: E501

        :return: The rune_address of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_address

    @rune_address.setter
    def rune_address(self, rune_address):
        """Sets the rune_address of this RUNEPoolProvider.

        address used by the member  # noqa: E501

        :param rune_address: The rune_address of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_address is None:
            raise ValueError("Invalid value for `rune_address`, must not be `None`")  # noqa: E501

        self._rune_address = rune_address

    @property
    def rune_deposit(self):
        """Gets the rune_deposit of this RUNEPoolProvider.  # noqa: E501

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :return: The rune_deposit of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_deposit

    @rune_deposit.setter
    def rune_deposit(self, rune_deposit):
        """Sets the rune_deposit of this RUNEPoolProvider.

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :param rune_deposit: The rune_deposit of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_deposit is None:
            raise ValueError("Invalid value for `rune_deposit`, must not be `None`")  # noqa: E501

        self._rune_deposit = rune_deposit

    @property
    def rune_withdrawn(self):
        """Gets the rune_withdrawn of this RUNEPoolProvider.  # noqa: E501

        Int64(e8), total asset withdrawn from the RUNEPool by the member  # noqa: E501

        :return: The rune_withdrawn of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_withdrawn

    @rune_withdrawn.setter
    def rune_withdrawn(self, rune_withdrawn):
        """Sets the rune_withdrawn of this RUNEPoolProvider.

        Int64(e8), total asset withdrawn from the RUNEPool by the member  # noqa: E501

        :param rune_withdrawn: The rune_withdrawn of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_withdrawn is None:
            raise ValueError("Invalid value for `rune_withdrawn`, must not be `None`")  # noqa: E501

        self._rune_withdrawn = rune_withdrawn

    @property
    def units(self):
        """Gets the units of this RUNEPoolProvider.  # noqa: E501

        Int64, units that belong the the member  # noqa: E501

        :return: The units of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RUNEPoolProvider.

        Int64, units that belong the the member  # noqa: E501

        :param units: The units of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RUNEPoolProvider, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RUNEPoolProvider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReserveItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'str',
        'gas_fee_outbound': 'str',
        'gas_reimbursement': 'str',
        'network_fee': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'end_time': 'endTime',
        'gas_fee_outbound': 'gasFeeOutbound',
        'gas_reimbursement': 'gasReimbursement',
        'network_fee': 'networkFee',
        'start_time': 'startTime'
    }

    def __init__(self, end_time=None, gas_fee_outbound=None, gas_reimbursement=None, network_fee=None, start_time=None):  # noqa: E501
        """ReserveItem - a model defined in Swagger"""  # noqa: E501
        self._end_time = None
        self._gas_fee_outbound = None
        self._gas_reimbursement = None
        self._network_fee = None
        self._start_time = None
        self.discriminator = None
        self.end_time = end_time
        self.gas_fee_outbound = gas_fee_outbound
        self.gas_reimbursement = gas_reimbursement
        self.network_fee = network_fee
        self.start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ReserveItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ReserveItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this ReserveItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def gas_fee_outbound(self):
        """Gets the gas_fee_outbound of this ReserveItem.  # noqa: E501

        Int64(e8), fee made from outbound  # noqa: E501

        :return: The gas_fee_outbound of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._gas_fee_outbound

    @gas_fee_outbound.setter
    def gas_fee_outbound(self, gas_fee_outbound):
        """Sets the gas_fee_outbound of this ReserveItem.

        Int64(e8), fee made from outbound  # noqa: E501

        :param gas_fee_outbound: The gas_fee_outbound of this ReserveItem.  # noqa: E501
        :type: str
        """
        if gas_fee_outbound is None:
            raise ValueError("Invalid value for `gas_fee_outbound`, must not be `None`")  # noqa: E501

        self._gas_fee_outbound = gas_fee_outbound

    @property
    def gas_reimbursement(self):
        """Gets the gas_reimbursement of this ReserveItem.  # noqa: E501

        Int64(e8), RUNE paid to the pool for compensating the gas fees  # noqa: E501

        :return: The gas_reimbursement of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._gas_reimbursement

    @gas_reimbursement.setter
    def gas_reimbursement(self, gas_reimbursement):
        """Sets the gas_reimbursement of this ReserveItem.

        Int64(e8), RUNE paid to the pool for compensating the gas fees  # noqa: E501

        :param gas_reimbursement: The gas_reimbursement of this ReserveItem.  # noqa: E501
        :type: str
        """
        if gas_reimbursement is None:
            raise ValueError("Invalid value for `gas_reimbursement`, must not be `None`")  # noqa: E501

        self._gas_reimbursement = gas_reimbursement

    @property
    def network_fee(self):
        """Gets the network_fee of this ReserveItem.  # noqa: E501

        Int64(e8), RUNE paid to the system on deposit, send messages   # noqa: E501

        :return: The network_fee of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._network_fee

    @network_fee.setter
    def network_fee(self, network_fee):
        """Sets the network_fee of this ReserveItem.

        Int64(e8), RUNE paid to the system on deposit, send messages   # noqa: E501

        :param network_fee: The network_fee of this ReserveItem.  # noqa: E501
        :type: str
        """
        if network_fee is None:
            raise ValueError("Invalid value for `network_fee`, must not be `None`")  # noqa: E501

        self._network_fee = network_fee

    @property
    def start_time(self):
        """Gets the start_time of this ReserveItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ReserveItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this ReserveItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReserveItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReserveItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RunePoolWithdrawMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affiliate_address': 'str',
        'affiliate_amount': 'str',
        'affiliate_basis_point': 'str',
        'basis_points': 'str',
        'units': 'str'
    }

    attribute_map = {
        'affiliate_address': 'affiliateAddress',
        'affiliate_amount': 'affiliateAmount',
        'affiliate_basis_point': 'affiliateBasisPoint',
        'basis_points': 'basisPoints',
        'units': 'units'
    }

    def __init__(self, affiliate_address=None, affiliate_amount=None, affiliate_basis_point=None, basis_points=None, units=None):  # noqa: E501
        """RunePoolWithdrawMetadata - a model defined in Swagger"""  # noqa: E501
        self._affiliate_address = None
        self._affiliate_amount = None
        self._affiliate_basis_point = None
        self._basis_points = None
        self._units = None
        self.discriminator = None
        self.affiliate_address = affiliate_address
        self.affiliate_amount = affiliate_amount
        self.affiliate_basis_point = affiliate_basis_point
        self.basis_points = basis_points
        self.units = units

    @property
    def affiliate_address(self):
        """Gets the affiliate_address of this RunePoolWithdrawMetadata.  # noqa: E501

        Transaction affiliate address  # noqa: E501

        :return: The affiliate_address of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_address

    @affiliate_address.setter
    def affiliate_address(self, affiliate_address):
        """Sets the affiliate_address of this RunePoolWithdrawMetadata.

        Transaction affiliate address  # noqa: E501

        :param affiliate_address: The affiliate_address of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_address is None:
            raise ValueError("Invalid value for `affiliate_address`, must not be `None`")  # noqa: E501

        self._affiliate_address = affiliate_address

    @property
    def affiliate_amount(self):
        """Gets the affiliate_amount of this RunePoolWithdrawMetadata.  # noqa: E501

        Int64, Transaction affiliate amount in rune  # noqa: E501

        :return: The affiliate_amount of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_amount

    @affiliate_amount.setter
    def affiliate_amount(self, affiliate_amount):
        """Sets the affiliate_amount of this RunePoolWithdrawMetadata.

        Int64, Transaction affiliate amount in rune  # noqa: E501

        :param affiliate_amount: The affiliate_amount of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_amount is None:
            raise ValueError("Invalid value for `affiliate_amount`, must not be `None`")  # noqa: E501

        self._affiliate_amount = affiliate_amount

    @property
    def affiliate_basis_point(self):
        """Gets the affiliate_basis_point of this RunePoolWithdrawMetadata.  # noqa: E501

        Transaction affiliate basis point  # noqa: E501

        :return: The affiliate_basis_point of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_basis_point

    @affiliate_basis_point.setter
    def affiliate_basis_point(self, affiliate_basis_point):
        """Sets the affiliate_basis_point of this RunePoolWithdrawMetadata.

        Transaction affiliate basis point  # noqa: E501

        :param affiliate_basis_point: The affiliate_basis_point of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_basis_point is None:
            raise ValueError("Invalid value for `affiliate_basis_point`, must not be `None`")  # noqa: E501

        self._affiliate_basis_point = affiliate_basis_point

    @property
    def basis_points(self):
        """Gets the basis_points of this RunePoolWithdrawMetadata.  # noqa: E501

        Int64 (Basis points, 0-10000, where 10000=100%), percentage of total ownership withdrawn   # noqa: E501

        :return: The basis_points of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._basis_points

    @basis_points.setter
    def basis_points(self, basis_points):
        """Sets the basis_points of this RunePoolWithdrawMetadata.

        Int64 (Basis points, 0-10000, where 10000=100%), percentage of total ownership withdrawn   # noqa: E501

        :param basis_points: The basis_points of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if basis_points is None:
            raise ValueError("Invalid value for `basis_points`, must not be `None`")  # noqa: E501

        self._basis_points = basis_points

    @property
    def units(self):
        """Gets the units of this RunePoolWithdrawMetadata.  # noqa: E501

        Int64, amount of units removed from the member as result of the withdrawal   # noqa: E501

        :return: The units of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RunePoolWithdrawMetadata.

        Int64, amount of units removed from the member as result of the withdrawal   # noqa: E501

        :param units: The units of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunePoolWithdrawMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunePoolWithdrawMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AffiliateHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'str',
        'end_time': 'str',
        'start_time': 'str',
        'thornames': 'list[ItemThorname]',
        'volume': 'str',
        'volume_usd': 'str'
    }

    attribute_map = {
        'count': 'count',
        'end_time': 'endTime',
        'start_time': 'startTime',
        'thornames': 'thornames',
        'volume': 'volume',
        'volume_usd': 'volumeUSD'
    }

    def __init__(self, count=None, end_time=None, start_time=None, thornames=None, volume=None, volume_usd=None):  # noqa: E501
        """AffiliateHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._end_time = None
        self._start_time = None
        self._thornames = None
        self._volume = None
        self._volume_usd = None
        self.discriminator = None
        self.count = count
        self.end_time = end_time
        self.start_time = start_time
        self.thornames = thornames
        self.volume = volume
        self.volume_usd = volume_usd

    @property
    def count(self):
        """Gets the count of this AffiliateHistoryItem.  # noqa: E501

        Int64, The count of affiliates during the time interval   # noqa: E501

        :return: The count of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this AffiliateHistoryItem.

        Int64, The count of affiliates during the time interval   # noqa: E501

        :param count: The count of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def end_time(self):
        """Gets the end_time of this AffiliateHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this AffiliateHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def start_time(self):
        """Gets the start_time of this AffiliateHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this AffiliateHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def thornames(self):
        """Gets the thornames of this AffiliateHistoryItem.  # noqa: E501


        :return: The thornames of this AffiliateHistoryItem.  # noqa: E501
        :rtype: list[ItemThorname]
        """
        return self._thornames

    @thornames.setter
    def thornames(self, thornames):
        """Sets the thornames of this AffiliateHistoryItem.


        :param thornames: The thornames of this AffiliateHistoryItem.  # noqa: E501
        :type: list[ItemThorname]
        """
        if thornames is None:
            raise ValueError("Invalid value for `thornames`, must not be `None`")  # noqa: E501

        self._thornames = thornames

    @property
    def volume(self):
        """Gets the volume of this AffiliateHistoryItem.  # noqa: E501

        Int64(e8), The total volume of the affiliates detonated in RUNE   # noqa: E501

        :return: The volume of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this AffiliateHistoryItem.

        Int64(e8), The total volume of the affiliates detonated in RUNE   # noqa: E501

        :param volume: The volume of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501

        self._volume = volume

    @property
    def volume_usd(self):
        """Gets the volume_usd of this AffiliateHistoryItem.  # noqa: E501

        Int64(e2), The total volume of the affiliates denoted in USD price of the rune in each swap   # noqa: E501

        :return: The volume_usd of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._volume_usd

    @volume_usd.setter
    def volume_usd(self, volume_usd):
        """Sets the volume_usd of this AffiliateHistoryItem.

        Int64(e2), The total volume of the affiliates denoted in USD price of the rune in each swap   # noqa: E501

        :param volume_usd: The volume_usd of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if volume_usd is None:
            raise ValueError("Invalid value for `volume_usd`, must not be `None`")  # noqa: E501

        self._volume_usd = volume_usd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AffiliateHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AffiliateHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ItemThorname(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'str',
        'thorname': 'str',
        'volume': 'str',
        'volume_usd': 'str'
    }

    attribute_map = {
        'count': 'count',
        'thorname': 'thorname',
        'volume': 'volume',
        'volume_usd': 'volumeUSD'
    }

    def __init__(self, count=None, thorname=None, volume=None, volume_usd=None):  # noqa: E501
        """ItemThorname - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._thorname = None
        self._volume = None
        self._volume_usd = None
        self.discriminator = None
        self.count = count
        self.thorname = thorname
        self.volume = volume
        self.volume_usd = volume_usd

    @property
    def count(self):
        """Gets the count of this ItemThorname.  # noqa: E501

        Int64, The count of affiliates with the same thorname during the time interval   # noqa: E501

        :return: The count of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ItemThorname.

        Int64, The count of affiliates with the same thorname during the time interval   # noqa: E501

        :param count: The count of this ItemThorname.  # noqa: E501
        :type: str
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def thorname(self):
        """Gets the thorname of this ItemThorname.  # noqa: E501

        thorname of the affiliate  # noqa: E501

        :return: The thorname of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._thorname

    @thorname.setter
    def thorname(self, thorname):
        """Sets the thorname of this ItemThorname.

        thorname of the affiliate  # noqa: E501

        :param thorname: The thorname of this ItemThorname.  # noqa: E501
        :type: str
        """
        if thorname is None:
            raise ValueError("Invalid value for `thorname`, must not be `None`")  # noqa: E501

        self._thorname = thorname

    @property
    def volume(self):
        """Gets the volume of this ItemThorname.  # noqa: E501

        Int64(e8), The volume of affiliates with the same thorname detonated in RUNE   # noqa: E501

        :return: The volume of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this ItemThorname.

        Int64(e8), The volume of affiliates with the same thorname detonated in RUNE   # noqa: E501

        :param volume: The volume of this ItemThorname.  # noqa: E501
        :type: str
        """
        if volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501

        self._volume = volume

    @property
    def volume_usd(self):
        """Gets the volume_usd of this ItemThorname.  # noqa: E501

        Int64(e2), The volume of affiliates with the same thorname denoted in USD price of the rune in each swap   # noqa: E501

        :return: The volume_usd of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._volume_usd

    @volume_usd.setter
    def volume_usd(self, volume_usd):
        """Sets the volume_usd of this ItemThorname.

        Int64(e2), The volume of affiliates with the same thorname denoted in USD price of the rune in each swap   # noqa: E501

        :param volume_usd: The volume_usd of this ItemThorname.  # noqa: E501
        :type: str
        """
        if volume_usd is None:
            raise ValueError("Invalid value for `volume_usd`, must not be `None`")  # noqa: E501

        self._volume_usd = volume_usd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemThorname, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemThorname):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ContractMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attributes': 'object',
        'contract_type': 'str',
        'funds': 'object',
        'msg': 'object'
    }

    attribute_map = {
        'attributes': 'attributes',
        'contract_type': 'contractType',
        'funds': 'funds',
        'msg': 'msg'
    }

    def __init__(self, attributes=None, contract_type=None, funds=None, msg=None):  # noqa: E501
        """ContractMetadata - a model defined in Swagger"""  # noqa: E501
        self._attributes = None
        self._contract_type = None
        self._funds = None
        self._msg = None
        self.discriminator = None
        self.attributes = attributes
        self.contract_type = contract_type
        if funds is not None:
            self.funds = funds
        if msg is not None:
            self.msg = msg

    @property
    def attributes(self):
        """Gets the attributes of this ContractMetadata.  # noqa: E501

        contract attributes emitted from its event  # noqa: E501

        :return: The attributes of this ContractMetadata.  # noqa: E501
        :rtype: object
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this ContractMetadata.

        contract attributes emitted from its event  # noqa: E501

        :param attributes: The attributes of this ContractMetadata.  # noqa: E501
        :type: object
        """
        if attributes is None:
            raise ValueError("Invalid value for `attributes`, must not be `None`")  # noqa: E501

        self._attributes = attributes

    @property
    def contract_type(self):
        """Gets the contract_type of this ContractMetadata.  # noqa: E501

        contract type defined by cosmwasm  # noqa: E501

        :return: The contract_type of this ContractMetadata.  # noqa: E501
        :rtype: str
        """
        return self._contract_type

    @contract_type.setter
    def contract_type(self, contract_type):
        """Sets the contract_type of this ContractMetadata.

        contract type defined by cosmwasm  # noqa: E501

        :param contract_type: The contract_type of this ContractMetadata.  # noqa: E501
        :type: str
        """
        if contract_type is None:
            raise ValueError("Invalid value for `contract_type`, must not be `None`")  # noqa: E501

        self._contract_type = contract_type

    @property
    def funds(self):
        """Gets the funds of this ContractMetadata.  # noqa: E501

        contract funds emitted from its event  # noqa: E501

        :return: The funds of this ContractMetadata.  # noqa: E501
        :rtype: object
        """
        return self._funds

    @funds.setter
    def funds(self, funds):
        """Sets the funds of this ContractMetadata.

        contract funds emitted from its event  # noqa: E501

        :param funds: The funds of this ContractMetadata.  # noqa: E501
        :type: object
        """

        self._funds = funds

    @property
    def msg(self):
        """Gets the msg of this ContractMetadata.  # noqa: E501

        contract massages emitted from its event  # noqa: E501

        :return: The msg of this ContractMetadata.  # noqa: E501
        :rtype: object
        """
        return self._msg

    @msg.setter
    def msg(self, msg):
        """Sets the msg of this ContractMetadata.

        contract massages emitted from its event  # noqa: E501

        :param msg: The msg of this ContractMetadata.  # noqa: E501
        :type: object
        """

        self._msg = msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContractMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContractMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
